# iparapheur-internal
iparapheur v5.x main core application.

The main link between every sub-services, integrating business code logic.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: DEVELOP
- Package version: 1.10.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://libriciel.fr](https://libriciel.fr)

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import iparapheur_internal
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import iparapheur_internal
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import iparapheur_internal
from pprint import pprint
from iparapheur_internal.apis.tags import admin_desk_api
from iparapheur_internal.model.error_response import ErrorResponse
from iparapheur_internal.model.page_hierarchised_desk_representation import PageHierarchisedDeskRepresentation
# Defining the host is optional and defaults to http://localhost:8080
# See configuration.py for a list of all supported configuration parameters.
configuration = iparapheur_internal.Configuration(
    host = "http://localhost:8080"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: spring_oauth
configuration = iparapheur_internal.Configuration(
    host = "http://localhost:8080",
    access_token = 'YOUR_ACCESS_TOKEN'
)

# Enter a context with an instance of the API client
with iparapheur_internal.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = admin_desk_api.AdminDeskApi(api_client)
    tenant_id = "tenantId_example" # str | Tenant id
collapse_all = False # bool | Collapse (or expand) desks in the tree hierarchy. (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='collapseAll', paramName='collapse_all', dataType='bool', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='Collapse (or expand) desks in the tree hierarchy.', unescapedDescription='Collapse (or expand) desks in the tree hierarchy.', baseType='null', defaultValue='False', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='False', jsonSchema='{
  "name" : "collapseAll",
  "in" : "query",
  "description" : "Collapse (or expand) desks in the tree hierarchy.",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "type" : "boolean",
    "default" : false
  }
}', isString=false, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=true, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=false, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='null', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='boolean', baseName='CollapseAllSchema', complexType='null', getter='getCollapseAll', setter='setCollapseAll', description='null', dataType='bool', datatypeWithEnum='bool', dataFormat='null', name='collapse_all', min='null', max='null', defaultValue='False', defaultValueWithParam=' = data.collapseAll;', baseType='bool', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='False', jsonSchema='{
  "type" : "boolean",
  "default" : false
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=true, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='CollapseAll', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
reverse_id_list = [
        "reverseIdList_example"
    ] # [str] | Reversed ID list. * If `collapseAll` is `true`, children of given desk IDs will be retrieved. * If `collapseAll` is `false`, children of given desk IDs won't be retrieved.  (optional)
page = 0 # int | Zero-based page index (0..N) (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='page', paramName='page', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='Zero-based page index (0..N)', unescapedDescription='Zero-based page index (0..N)', baseType='null', defaultValue='0', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='0', jsonSchema='{
  "name" : "page",
  "in" : "query",
  "description" : "Zero-based page index (0..N)",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "minimum" : 0,
    "type" : "integer",
    "default" : 0
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=true, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='0', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='PageSchema', complexType='null', getter='getPage', setter='setPage', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='page', min='null', max='null', defaultValue='0', defaultValueWithParam=' = data.page;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='0', jsonSchema='{
  "minimum" : 0,
  "type" : "integer",
  "default" : 0
}', minimum='0', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=true, isInherited=false, discriminatorValue='null', nameInCamelCase='Page', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
size = 10 # int | The size of the page to be returned (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='size', paramName='size', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='The size of the page to be returned', unescapedDescription='The size of the page to be returned', baseType='null', defaultValue='10', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='10', jsonSchema='{
  "name" : "size",
  "in" : "query",
  "description" : "The size of the page to be returned",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "minimum" : 1,
    "type" : "integer",
    "default" : 10
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=true, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='1', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='SizeSchema', complexType='null', getter='getSize', setter='setSize', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='size', min='null', max='null', defaultValue='10', defaultValueWithParam=' = data.size;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='10', jsonSchema='{
  "minimum" : 1,
  "type" : "integer",
  "default" : 10
}', minimum='1', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=true, isInherited=false, discriminatorValue='null', nameInCamelCase='Size', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
sort = ["SUBSTITUTE_DESK,ASC"] # [str] | Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported. (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=true, isCollectionFormatMulti=true, isPrimitiveType=false, isModel=false, isExplode=true, baseName='sort', paramName='sort', dataType='[str]', datatypeWithEnum='null', dataFormat='null', collectionFormat='multi', description='Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.', unescapedDescription='Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.', baseType='null', defaultValue='["SUBSTITUTE_DESK,ASC"]', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='["SUBSTITUTE_DESK,ASC"]', jsonSchema='{
  "name" : "sort",
  "in" : "query",
  "description" : "Sorting criteria in the format: property,(asc|desc). Default sort order is ascending. Multiple sort criteria are supported.",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "type" : "array",
    "items" : {
      "type" : "string"
    },
    "default" : [ "SUBSTITUTE_DESK,ASC" ]
  }
}', isString=false, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isAnyType=false, isArray=true, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='string', baseName='inner', complexType='null', getter='getInner', setter='setInner', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='inner', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.inner;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='"string_example"', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Inner', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=false, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='null', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='array', baseName='SortSchema', complexType='null', getter='getSort', setter='setSort', description='null', dataType='[str]', datatypeWithEnum='[str]', dataFormat='null', name='sort', min='null', max='null', defaultValue='["SUBSTITUTE_DESK,ASC"]', defaultValueWithParam=' = data.sort;', baseType='list', containerType='array', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='["SUBSTITUTE_DESK,ASC"]', jsonSchema='{
  "type" : "array",
  "items" : {
    "type" : "string"
  },
  "default" : [ "SUBSTITUTE_DESK,ASC" ]
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=true, isString=false, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=true, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=CodegenProperty{openApiType='string', baseName='items', complexType='null', getter='getItems', setter='setItems', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='items', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.items;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='"string_example"', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Items', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=CodegenProperty{openApiType='string', baseName='items', complexType='null', getter='getItems', setter='setItems', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='items', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.items;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='"string_example"', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isShort=false, isLong=false, isUnboundedInteger=false, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isPassword=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, isNew=false, isOverridden=null, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Items', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Sort', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
search_term = "searchTerm_example" # str | Searching for a specific desk name (optional)

    try:
        # List desks
        api_response = api_instance.list_hierarchic_desks(tenant_idcollapse_all=collapse_allreverse_id_list=reverse_id_listpage=pagesize=sizesort=sortsearch_term=search_term)
        pprint(api_response)
    except iparapheur_internal.ApiException as e:
        print("Exception when calling AdminDeskApi->list_hierarchic_desks: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8080*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminDeskApi* | [**list_hierarchic_desks**](docs/apis/tags/AdminDeskApi.md#list_hierarchic_desks) | **get** /api/internal/admin/tenant/{tenantId}/desk | List desks
*AdminLayerApi* | [**create_file_stamp**](docs/apis/tags/AdminLayerApi.md#create_file_stamp) | **post** /api/internal/admin/tenant/{tenantId}/layer/{layerId}/stamp | Create a file stamp
*AdminLayerApi* | [**create_layer**](docs/apis/tags/AdminLayerApi.md#create_layer) | **post** /api/internal/admin/tenant/{tenantId}/layer | Create a layer
*AdminLayerApi* | [**delete_file_stamp**](docs/apis/tags/AdminLayerApi.md#delete_file_stamp) | **delete** /api/internal/admin/tenant/{tenantId}/layer/{layerId}/stamp/{stampId} | Delete a stored image stamp
*AdminLayerApi* | [**delete_layer**](docs/apis/tags/AdminLayerApi.md#delete_layer) | **delete** /api/internal/admin/tenant/{tenantId}/layer/{layerId} | Delete layer
*AdminLayerApi* | [**get_layer**](docs/apis/tags/AdminLayerApi.md#get_layer) | **get** /api/internal/admin/tenant/{tenantId}/layer/{layerId} | Get a layer with every information set
*AdminLayerApi* | [**get_layer_example_pdf**](docs/apis/tags/AdminLayerApi.md#get_layer_example_pdf) | **post** /api/internal/admin/tenant/{tenantId}/layer/example-pdf | Test the given layer on a blank PDF
*AdminLayerApi* | [**list_layers**](docs/apis/tags/AdminLayerApi.md#list_layers) | **get** /api/internal/admin/tenant/{tenantId}/layer | List layers
*AdminLayerApi* | [**update_layer**](docs/apis/tags/AdminLayerApi.md#update_layer) | **put** /api/internal/admin/tenant/{tenantId}/layer/{layerId} | Edit a layer
*AdminSealCertificateApi* | [**get_seal_signature_image**](docs/apis/tags/AdminSealCertificateApi.md#get_seal_signature_image) | **get** /api/internal/admin/tenant/{tenantId}/sealCertificate/{sealCertificateId}/signatureImage | Get seal&#x27;s signature image
*AdminSealCertificateApi* | [**list_subtype_usage**](docs/apis/tags/AdminSealCertificateApi.md#list_subtype_usage) | **get** /api/internal/admin/tenant/{tenantId}/sealCertificate/{sealCertificateId}/subtypeUsage | List subtypes using the given certificate
*AdminTemplateApi* | [**test_docket_pdf_template**](docs/apis/tags/AdminTemplateApi.md#test_docket_pdf_template) | **post** /api/internal/admin/tenant/{tenantId}/test-docket-pdf-template | Test the given docket PDF template
*AdminTemplateApi* | [**test_mail_template**](docs/apis/tags/AdminTemplateApi.md#test_mail_template) | **post** /api/internal/admin/tenant/{tenantId}/test-mail-template | Test the given mail template
*AdminTemplateApi* | [**test_signature_pdf_template**](docs/apis/tags/AdminTemplateApi.md#test_signature_pdf_template) | **post** /api/internal/admin/tenant/{tenantId}/test-signature-pdf-template | Get the server default signature template
*AdminTrashBinApi* | [**list_trash_bin_listable_folders**](docs/apis/tags/AdminTrashBinApi.md#list_trash_bin_listable_folders) | **get** /api/internal/admin/tenant/{tenantId}/trash-bin | List folders in the trash-bin
*AdminTypologyApi* | [**get_typology_hierarchy**](docs/apis/tags/AdminTypologyApi.md#get_typology_hierarchy) | **get** /api/internal/admin/tenant/{tenantId}/typology | Get typology list, sorted by hierarchy.
*CurrentUserApi* | [**update_current_user_password**](docs/apis/tags/CurrentUserApi.md#update_current_user_password) | **put** /api/internal/currentUser/password | Update user password
*DeskApi* | [**get_associated_desks**](docs/apis/tags/DeskApi.md#get_associated_desks) | **get** /api/internal/tenant/{tenantId}/desk/{deskId}/associatedDesks | Get the target desk&#x27;s associated ones
*FolderApi* | [**list_folders**](docs/apis/tags/FolderApi.md#list_folders) | **post** /api/internal/tenant/{tenantId}/desk/{deskId}/search/{state} | Query folders
*ServerInfoApi* | [**get_gdpr_properties**](docs/apis/tags/ServerInfoApi.md#get_gdpr_properties) | **get** /api/internal/serverInfo/gdpr | Get the GDPR definition
*ServerInfoApi* | [**get_password_policies**](docs/apis/tags/ServerInfoApi.md#get_password_policies) | **get** /api/internal/serverInfo/passwordPolicies | Get Password rules for the server
*TemplateApi* | [**test_signature_template**](docs/apis/tags/TemplateApi.md#test_signature_template) | **post** /api/internal/tenant/{tenantId}/templates/{templateType}/example | Test the tenant signature template
*TypologyApi* | [**get_subtype**](docs/apis/tags/TypologyApi.md#get_subtype) | **get** /api/internal/tenant/{tenantId}/typology/type/{typeId}/subtype/{subtypeId} | Get a subtype
*TypologyApi* | [**get_type**](docs/apis/tags/TypologyApi.md#get_type) | **get** /api/internal/tenant/{tenantId}/typology/type/{typeId} | Get a type with every informations set
*WorkflowApi* | [**get_workflow_definition**](docs/apis/tags/WorkflowApi.md#get_workflow_definition) | **get** /api/internal/tenant/{tenantId}/desk/{deskId}/workflow-definition/{workflowDefinitionKey} | Get a workflow definition with every information set

## Documentation For Models

 - [Action](docs/models/Action.md)
 - [DeskRepresentation](docs/models/DeskRepresentation.md)
 - [DetachedSignature](docs/models/DetachedSignature.md)
 - [DocumentDto](docs/models/DocumentDto.md)
 - [ErrorResponse](docs/models/ErrorResponse.md)
 - [ExternalSignatureConfigRepresentation](docs/models/ExternalSignatureConfigRepresentation.md)
 - [ExternalSignatureProvider](docs/models/ExternalSignatureProvider.md)
 - [ExternalState](docs/models/ExternalState.md)
 - [FolderDto](docs/models/FolderDto.md)
 - [FolderFilterDto](docs/models/FolderFilterDto.md)
 - [FolderListableDto](docs/models/FolderListableDto.md)
 - [FolderSortBy](docs/models/FolderSortBy.md)
 - [GdprApplication](docs/models/GdprApplication.md)
 - [GdprCookie](docs/models/GdprCookie.md)
 - [GdprDataElement](docs/models/GdprDataElement.md)
 - [GdprDataSet](docs/models/GdprDataSet.md)
 - [GdprDeclaringEntity](docs/models/GdprDeclaringEntity.md)
 - [GdprDeclaringEntityDpo](docs/models/GdprDeclaringEntityDpo.md)
 - [GdprDeclaringEntityResponsible](docs/models/GdprDeclaringEntityResponsible.md)
 - [GdprEntity](docs/models/GdprEntity.md)
 - [GdprProperties](docs/models/GdprProperties.md)
 - [HierarchisedDeskRepresentation](docs/models/HierarchisedDeskRepresentation.md)
 - [LayerDto](docs/models/LayerDto.md)
 - [LayerRepresentation](docs/models/LayerRepresentation.md)
 - [MailTemplateTestRequest](docs/models/MailTemplateTestRequest.md)
 - [MediaType](docs/models/MediaType.md)
 - [MetadataDto](docs/models/MetadataDto.md)
 - [MetadataType](docs/models/MetadataType.md)
 - [PageDeskRepresentation](docs/models/PageDeskRepresentation.md)
 - [PageFolderDto](docs/models/PageFolderDto.md)
 - [PageFolderListableDto](docs/models/PageFolderListableDto.md)
 - [PageHierarchisedDeskRepresentation](docs/models/PageHierarchisedDeskRepresentation.md)
 - [PageInfo](docs/models/PageInfo.md)
 - [PageLayerRepresentation](docs/models/PageLayerRepresentation.md)
 - [PageSubtypeRepresentation](docs/models/PageSubtypeRepresentation.md)
 - [PageTypologyRepresentation](docs/models/PageTypologyRepresentation.md)
 - [PageableObject](docs/models/PageableObject.md)
 - [PasswordPolicies](docs/models/PasswordPolicies.md)
 - [PdfSignaturePosition](docs/models/PdfSignaturePosition.md)
 - [PdfTemplateTestRequest](docs/models/PdfTemplateTestRequest.md)
 - [SealCertificateRepresentation](docs/models/SealCertificateRepresentation.md)
 - [SignatureFormat](docs/models/SignatureFormat.md)
 - [SignatureInfo](docs/models/SignatureInfo.md)
 - [SignaturePlacement](docs/models/SignaturePlacement.md)
 - [SignatureProtocol](docs/models/SignatureProtocol.md)
 - [SortObject](docs/models/SortObject.md)
 - [StampDto](docs/models/StampDto.md)
 - [StampTextColor](docs/models/StampTextColor.md)
 - [StampType](docs/models/StampType.md)
 - [State](docs/models/State.md)
 - [StepDefinitionDto](docs/models/StepDefinitionDto.md)
 - [StepDefinitionParallelType](docs/models/StepDefinitionParallelType.md)
 - [StepDefinitionType](docs/models/StepDefinitionType.md)
 - [SubtypeDto](docs/models/SubtypeDto.md)
 - [SubtypeLayerAssociation](docs/models/SubtypeLayerAssociation.md)
 - [SubtypeLayerDto](docs/models/SubtypeLayerDto.md)
 - [SubtypeMetadataDto](docs/models/SubtypeMetadataDto.md)
 - [SubtypeRepresentation](docs/models/SubtypeRepresentation.md)
 - [Task](docs/models/Task.md)
 - [TemplateType](docs/models/TemplateType.md)
 - [TenantRepresentation](docs/models/TenantRepresentation.md)
 - [TypeDto](docs/models/TypeDto.md)
 - [TypologyRepresentation](docs/models/TypologyRepresentation.md)
 - [UserDto](docs/models/UserDto.md)
 - [UserPrivilege](docs/models/UserPrivilege.md)
 - [UserRepresentation](docs/models/UserRepresentation.md)
 - [WorkflowDefinitionDto](docs/models/WorkflowDefinitionDto.md)

## Documentation For Authorization

 Authentication schemes defined for the API:
## spring_oauth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: ./auth/realms/api/protocol/openid-connect/auth
- **Scopes**: N/A


## Author

iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop
iparapheur@libriciel.coop

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in iparapheur_internal.apis and iparapheur_internal.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from iparapheur_internal.apis.default_api import DefaultApi`
- `from iparapheur_internal.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import iparapheur_internal
from iparapheur_internal.apis import *
from iparapheur_internal.models import *
```
